@@ -5,7 +5,7 @@ class Imp < Formula
   homepage 'https://integrativemodeling.org/'
   url 'https://integrativemodeling.org/2.8.0/download/imp-2.8.0.tar.gz'
   sha256 '83a23c56f0be9de8900d0edd3978eb8c2637e6d5086f7ef7e2cd61f0b7a5aa80'
-  revision 10
+  revision 13
 
   # Fix to work with latest CGAL (4.11)
   patch do
@@ -20,8 +20,8 @@ class Imp < Formula
   depends_on 'cmake' => :build
   depends_on 'swig' => :build
 
-  depends_on :python => :recommended
-  depends_on :python3 => :recommended
+  depends_on 'python@2' => :recommended
+  depends_on 'python' => :recommended
 
   depends_on 'boost'
   depends_on 'hdf5'
@@ -35,7 +35,7 @@ class Imp < Formula
   needs :cxx11 if OS.linux?
 
   def install
-    pyver = Language::Python.major_minor_version "python"
+    pyver = Language::Python.major_minor_version "python2.7"
     args = std_cmake_args
     args << "-DIMP_DISABLED_MODULES=scratch"
     args << ".."
@@ -49,9 +49,9 @@ class Imp < Formula
       system "cmake", *args
       system "make"
       system "make", "install"
-      if build.with? 'python3'
+      if build.with? 'python'
         version = Language::Python.major_minor_version "python3"
-        python_framework = (Formula["python3"].opt_prefix)/"Frameworks/Python.framework/Versions/#{version}"
+        python_framework = (Formula["python"].opt_prefix)/"Frameworks/Python.framework/Versions/#{version}"
         py3_lib = "#{python_framework}/lib/libpython#{version}.dylib"
         py3_inc = "#{python_framework}/Headers"
         args = ["..",
